==> wocket-0.1.5-20191016.190712-3.jar: META-INF/leiningen/stigmergy/wocket/README.md <==
# wocket

A async messaging library for communicating between clojure and clojurescript via websockets. Future plan to add
WebRTC.

# Dependency

    [com.kaicode/wocket "0.1.5-SNAPSHOT"] 
    
# Quick Start

See [chat demo](/example-project) for a complete example.

## Server-side Clojure setup

Setup a route for Websocket connection

```Clojure
(defroute app
    (GET "/ws" [] ws/listen-for-client-websocket-connection))
```

## Client-side ClojureScript setup

Connect to Clojure websocket server

```Clojure
(require [com.kaicode.wocket.client :as ws :refer [process-msg]])

(ws/connect-to-websocket-server {:port 3000}) ;; change the port for your configuration

```

# Send messages between ClojureScript <-> Clojure

Once browser is connected to the websocket server, cljs can send messages to the clj server like this

```Clojure
(ws/send! [:msg-tag msg-payload])

```

:msg-tag can be any arbitary value, but a descriptive keyword should be used. 
message-payload can be any arbitary value.

The Clojure server can receive and respond to the message by defining a multi-method 

```Clojure
(defmethod process-msg :msg-tag [ [client-websocket-channel [msg-tag msg-payload]] ]
    ;;do something with the msg-payload from cljs
    (prn "msg-payload from cljs " msg-payload)

    ;;send something back to cljs using the core.async channel client-socket-channel
    (ws/send! client-websocket-channel [:msg-tag-respond "I hear you"])
)
```
Likewise, the cljs client can recieve the message from the server with a multi-method

```Clojure
(defmethod process-msg :msg-tag-respond [ [_ msg-respond]]
    (prn "message from server " msg-respond)
)
```

==> wocket-0.1.5-20200227.103633-7.jar: META-INF/leiningen/stigmergy/wocket/README.md <==
# wocket

A async messaging library for communicating between clojure and clojurescript via websockets. Future plan to add
WebRTC.

# Dependency

    [stigmergy/wocket "0.1.5-SNAPSHOT"] 
    
# Quick Start

See [chat demo](/example-project) for a complete example.

## Server-side Clojure setup

Setup a route for Websocket connection

```Clojure
(defroute app
    (GET "/ws" [] ws/listen-for-client-websocket-connection))
```

## Client-side ClojureScript setup

Connect to Clojure websocket server

```Clojure
(require [stigmergy.wocket.client :as ws :refer [process-msg]])

(ws/connect-to-websocket-server {:port 3000}) ;; change the port for your configuration

```

# Send messages between ClojureScript <-> Clojure

Once browser is connected to the websocket server, cljs can send messages to the clj server like this

```Clojure
(ws/send! [:msg-tag msg-payload])

```

:msg-tag can be any arbitary value, but a descriptive keyword should be used. 
message-payload can be any arbitary value.

The Clojure server can receive and respond to the message by defining a multi-method 

```Clojure
(defmethod process-msg :msg-tag [ [client-websocket-channel [msg-tag msg-payload]] ]
    ;;do something with the msg-payload from cljs
    (prn "msg-payload from cljs " msg-payload)

    ;;send something back to cljs using the core.async channel client-socket-channel
    (ws/send! client-websocket-channel [:msg-tag-respond "I hear you"])
)
```
Likewise, the cljs client can recieve the message from the server with a multi-method

```Clojure
(defmethod process-msg :msg-tag-respond [ [_ msg-respond]]
    (prn "message from server " msg-respond)
)
```
